@@ -115,7 +115,7 @@ int pthread_attr_getinheritsched(const pthread_attr_t *attr, int *inheritsched)
     return pth_error(ENOSYS, ENOSYS);
 }
 
-int pthread_attr_setschedparam(pthread_attr_t *attr, struct sched_param *schedparam)
+int pthread_attr_setschedparam(pthread_attr_t *attr, const struct sched_param *schedparam)
 {
     if (attr == NULL)
         return pth_error(EINVAL, EINVAL);
